# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['nautobot_golden_config',
 'nautobot_golden_config.api',
 'nautobot_golden_config.migrations',
 'nautobot_golden_config.nornir_plays',
 'nautobot_golden_config.tests',
 'nautobot_golden_config.utilities']

package_data = \
{'': ['*'], 'nautobot_golden_config': ['templates/nautobot_golden_config/*']}

install_requires = \
['matplotlib>=3.3.2,<4.0.0',
 'nautobot-plugin-nornir>=0.9.0,<0.10.0',
 'nautobot>=1.0.0-alpha.1,<2.0.0']

setup_kwargs = {
    'name': 'nautobot-golden-config',
    'version': '0.9.0',
    'description': 'A plugin for configuration on nautobot',
    'long_description': '# nautobot-golden-config\n\nA plugin for [Nautobot](https://github.com/nautobot/nautobot) that intends to provide context around golden configuration.\n\nIn addition to this overview, documentation can be found for:\n\n- [Navigating Overview](./docs/navigating-golden.md)\n- [Navigating Backup](./docs/navigating-backup.md)\n- [Navigating Compliance](./docs/navigating-compliance.md)\n- [Navigating Intended](./docs/navigating-intended.md)\n- [Navigating SoTAgg](./docs/navigating-sotagg.md)\n- [FAQ](./docs/FAQ.md)\n\n# Overview\n\nThe golden configuration plugin performs four primary actions, each of which can be toggled on with a respective `enable_*` setting, covered in detail \nlater in the readme. \n\n* Configuration Backup - Is a Nornir process to connect to devices, optionally parse out lines/secrets, backup the configuration, and save to a Git repository.\n* Configuration Intended - Is a Nornir process to generate configuration based on a Git repo of Jinja files and a Git repo to store the intended configuration.\n* Source of Truth Aggregation - Is a GraphQL query per device with that creates a data structure used in the generation of configuration.\n* Configuration Compliance - This is a comparison of the actual (via backups) and intended (via Jinja file creation) cli configurations.\n\nThe operator\'s of their own Nautobot instance are welcome to use any combination of these features. Though the appearance may seem like they are tightly \ncoupled, they are not actually. As an example, once can obtain backup configurations from their current RANCID/Oxidized process and simply provide a Git Repo\nof the location of the backup configurations and the compliance process would work the same way. Another user may only want to generate configurations.\n\n## Screenshots\n\nThere are many features and capabilities the plugin provides, the following is intended to provide a quick visual overview of some of those features.\n\nThe golden configuration is driven by jobs that run a series of tasks and the result is captured in this overview.\n\n![Compliance Feature](./docs/img/golden-overview.png)\n\nThe compliance report provides a high-level overview on the compliance of your network.\n![Compliance Report](./docs/img/compliance-report.png)\n\nThe compliance overview will provide a per device and feature overview on the compliance of your network devices.\n![Compliance Overview](./docs/img/compliance-overview.png)\n\nDrilling into a specfic device and feature, you can get an immediate detailed understanding of your device.\n![Compliance Device](./docs/img/compliance-device.png)\n\n![Compliance Feature](./docs/img/compliance-feature.png)\n\n## Settings\n\nThere are three primary controls to determine the inclusion of a device within one of the four given components.\n\n* The `allowed_os` will allow list the specific operating systems that can be included.\n* The `enable_backup`, `enable_compliance`, `enable_intended`, and `enable_sotagg` will toggle inclusion of the entire component.\n* There is the ability to manage on a per device element TODO: Needs to be updated after more correctly implemented.\n\n## Configuration Backup\n\nThe backup configuration process relies on the ability for the nautobot worker to connect via Nornir to the device, run the `show run` or equivalent command \nand save the configuration. The high-level process to run backups is:\n\n* Download the latest Git repository, based on `backup config` type Git repo within Nautobot.\n* Run a Nornir play to obtain the cli configurations.\n* Optionally perform some lightweight processing of the backup.\n* Store the backup configurations locally.\n* Push configurations to the remote Git repository.\n\n### Configuration Backup Settings\n\nBackup configurations often need some amount of parsing to stay sane. The two obvious use cases are the ability to remove lines such as the "Last \nConfiguration" changed date, as this will cause unnecessary changes the second is to strip out secrets from the configuration. In an effort to support these \nuses cases, the following settings are available.\n\n* Remove Lines - provides the ability to remove a line based on a regex match.\n* Substitute Lines - provides the ability to swap out parts of a line based on a regex match.\n\nTODO: Document when ideally it is in the UI and not in config context, for now, can reference [here](https://github.com/networktocode-llc/nautobot-gc-data/blob/be82d7f686a573ad33f85b2313e632d9bc2e7910/config_contexts/all.yml#L197-L214)\n\nBackup configurations rely on a Git Repo, and the plugin registers an additional repository for Git source this access. Within the Nautobot Git repositories, there will be a `backup config` option, which there must be one and only one configured for the process to work.\n\nTODO: insert screenshot\n\nThe `backup_path_template` provides the ability to dynamically state per device where the configurations should end up in the file structure. Every device \nthere is a Django ORM object, tied to the model instance of a `Device` model, and that is represented as `obj`. That means that any valid Device model method is available. This is then compiled via Jinja. This may seem complicated, but the equivalent of `obj` by example would be:\n\n```python\nobj = Device.objects.get(name="nyc-rt01")\n```\n\nAn example would be:\n```python\nbackup_path_template = "{{obj.site.slug}}/{{obj.name}}.cfg"\n```\n\nThe backup process will automatically create folders as required based on the path definition. \n\n## Configuration Compliance \n\nThe following should be noted by what is meant by configuration compliance. Configurations are considered to be compliant if the generated configuration \n(generally by merging data and Jinja2, will be referred to as the intended configuration from hence forth) matches "exactly" as the actual configuration is \non the backup. This may confusing to some, as for example to the average network engineer, there is no difference between `int g0/0` and\n`interface GigabitEthernet0/0` but for the purpose of configuration compliance, it is not a match... full stop.\n\nIt\'s helpful to understand what are some common reasons a device is not compliant.\n\n* There is missing configuration on the device.\n* There is extra configuration on the device.\n* The data used to generate the configuration is incorrect, and created a "false positive".\n* The template used to generate the configuration is incorrect, and created a "false positive".\n* The parser used to obtain the configuration from the feature is incorrect, and created a "false positive".\n\nThere is no magic to determine the state of configuration. You still must define what is good configuration and compare it. There are several reasons why \nconfiguration may be as a network engineer wants it, but the tool correctly considers it non-compliant, since the tool is only comparing two configurations.\nThe tool makes no assumptions to determine what an engineer may want to do, but did not document via the configuration generation process.\n\n### Configuration Compliance Parsing Engine\n\nConfiguration compliance is different then a simple unix diff. While the UI provides both, the compliance metrics are not influenced by the unix diff \ncapabilities. One of the challenges of getting a device into compliance is the ramp up it takes to model and generate configurations for an entire \nconfiguration. The compliance engine has several features to better build out this process.\n\n1. The ability to parse into smaller sections, given a list of root configuration elements.\n2. The ability to consider ordered and non-ordered configurations.\n3. The ability to dynamically understand parent/child relationships within the configurations.\n\nIn regards to `1`, consider the following example of how to obtain service configurations:\n```\nservice\nno service\n```\nSpecific configurations that start with either of these commands can be grouped together.\n\nIn regards to `2`, consider the configurations of SNMP on a nexus switch. \n```\nsnmp-server community secure group network-admin\nsnmp-server community networktocode group network-operator\n```\n\nThe above configurations are rendered based on the order in which they were entered, not based on the a deterministic way. The comparison process takes this into consideration. \n\nIn regards to `3`, consider the following example of BGP configuration. \n```\nrouter bgp\nprefix-list\n```\nAll configurations that are a parent and child relationships would be considered within the parsing engine. Additionally, if one configuration line was \nwrong, only that line and the parents would be shown, not all lines or only the missing configuration without context of the parents, e.g. Given:\n\nActual\n```\nrouter bgp 65250\n  router-id 10.0.10.5\n  log-neighbor-changes\n  address-family ipv4 unicast\n    redistribute direct route-map PERMIT_CONN_ROUTES\n  neighbor 10.10.10.5\n    remote-as 65250\n    address-family ipv4 unicast\n```\n\nIntended\n```\nrouter bgp 65250\n  router-id 10.0.10.6\n  log-neighbor-changes\n  address-family ipv4 unicast\n    redistribute direct route-map PERMIT_CONN_ROUTES\n  neighbor 10.10.10.5\n    remote-as 65250\n    address-family ipv4 unicast\n```\nWould result in the identfying the missing configurations as:\n\n```\nrouter bgp 65250\n  router-id 10.0.10.6\n```\n\n### Configuration Compliance Settings\n\nConfiguration compliance requires the Git Repo settings for `config backups` and `intended configs`--which are covered in their respective sections--regardless if they are actually managed via the plugin or not.\n\nThe Configuration compliance feature map must be created per the operator. \n\nTODO: Once move the UI, document for now an example can be found [here](https://github.com/networktocode-llc/nautobot-gc-data/blob/be82d7f686a573ad33f85b2313e632d9bc2e7910/config_contexts/all.yml#L7-L196)\n\n## Intended Configuration Generation\n\nThe Golden Config plugin provides the ability to generate configurations. The process is a Nornir play that points to a single Jinja template per \ndevice that generates the configurations. Data is provided via the Source of Truth aggregation and is currently a hard requirement to be turned on if \ngenerating configuration via the Golden Config plugin. Whatever data is returned by the Source of Truth Aggregation is available to the Jinja template.\n\nAs previous stated, there can only be a single template per device. It is often advantageous to break configurations into smaller snippets. A common pattern \nto overcome is:\n\n```jinja\n!\n{% include os ~ \'/services.j2\' %}\n!\n{% include os ~ \'/hostname.j2\' %}\n!\n{% include os ~ \'/ntp.j2\' %}\n!\n```\nor \n\n```jinja\n!\n{% set features = [\'services\', \'hostname\', \'ntp\'] %}\n{% for feature in features %}\n{% include os ~ \'/\' ~ feature ~ \'.j2\' %}\n!\n{% endfor %}\n```\n\n### Intended Configuration Settings\n\nThe configuration generation requires three components in addition to what was covered in the overall settings.\n\n1. The creation of a Git Repo for "Intended Config".\n2. The creation of a Git Repo for "Jinja Templates".\n3. The `intended_path_template` configuration parameter.\n4. The `jinja_path_template` configuration parameter.\n\nThe Git Repo\'s and path templates follow the same philosophy as those reviewed in the backup configuration. Please refer to that section for further details.\n\n# Installation\n\n> The plugin is compatible with Nautobot 1.0.0 and higher\n\nOnce installed, the plugin needs to be enabled in your `configuration.py` for both plugins\n\n```python\nPLUGINS = ["nautobot_plugin_nornir", "nautobot_golden_config"]\n\nPLUGINS_CONFIG = {\n    "nautobot_plugin_nornir": {\n        "nornir_settings": {\n            "credentials": "nautobot_plugin_nornir.plugins.credentials.env_vars.CredentialsEnvVars",\n            "runner": {\n                "plugin": "threaded",\n                "options": {\n                    "num_workers": 20,\n                },\n            },\n        },\n    },\n    "nautobot_golden_config": {\n        "allowed_os": os.environ.get("ALLOWED_OS", "all").split(","),\n        "per_feature_bar_width": float(os.environ.get("PER_FEATURE_BAR_WIDTH", 0.15)),\n        "per_feature_width": int(os.environ.get("PER_FEATURE_WIDTH", 13)),\n        "per_feature_height": int(os.environ.get("PER_FEATURE_HEIGHT", 4)),\n        "enable_backup": is_truthy(os.environ.get("ENABLE_BACKUP", True)),\n        "enable_compliance": is_truthy(os.environ.get("ENABLE_COMPLIANCE", True)),\n        "enable_intended": is_truthy(os.environ.get("ENABLE_INTENDED", True)),\n        "enable_sotagg": is_truthy(os.environ.get("ENABLE_SOTAGG", True)),\n        "sot_agg_transposer": os.environ.get("SOT_AGG_TRANSPOSER"),\n    },\n}\n\n```\n\nThe plugin behavior can be controlled with the following list of settings. \n\n| Key     | Example | Default | Description                          |\n| ------- | ------ | -------- | ------------------------------------- |\n| allowed_os | [cisco_ios, arista_eos] | [all] | A list of platforms supported, identified by the `platform_slug`, with special consideration for `all`. |\n| enable_backup | True | True | A boolean to represent whether or not to run backup configurations within the plugin. |\n| enable_compliance | True | True | A boolean to represent whether or not to run the compliance process within the plugin. |\n| enable_intended | True | True | A boolean to represent whether or not to generate intended configurations within the plugin. |\n| enable_sotagg | True | True | A boolean to represent whether or not to provide a GraphQL query per device to allow the intended configuration to provide data variables to the plugin. |\n| per_feature_bar_width | 0.15 | 0.15 | The width of the table bar within the overview report | \n| per_feature_width | 13 | 13 | The width in inches that the overview table can be. | \n| per_feature_height | 4 | 4 | The height in inches that the overview table can be. | \n| sot_agg_transposer | mypkg.transposer | - | A string representation of a function that can post-process the graphQL data. |\n\n> Note: Over time the intention is to make the compliance report more dynamic, but for now allow users to configure in a way that fits best for them.\n\n\n## API\n\nThere is no way to currently run the script via an API, this would be helpful to use in the configuration compliance workflow, and will be a future feature.\n\n# Contributing\n\nPull requests are welcomed and automatically built and tested against multiple version of Python and multiple version of Nautobot through TravisCI.\n\nThe project is packaged with a light development environment based on `docker-compose` to help with the local development of the project and to run the tests within TravisCI.\n\nThe project is following Network to Code software development guideline and is leveraging:\n- Black, Pylint, Bandit, flake8, and pydocstyle for Python linting and formatting.\n- Django unit test to ensure the plugin is working properly.\n\n## CLI Helper Commands\n\nThe project is coming with a CLI helper based on [invoke](http://www.pyinvoke.org/) to help setup the development environment. The commands are listed below in 3 categories `dev environment`, `utility` and `testing`. \n\nEach command can be executed with `invoke <command>`. All commands support the arguments `--nautobot-ver` and `--python-ver` if you want to manually define the version of Python and Nautobot to use. Each command also has its own help `invoke <command> --help`\n\n### Local dev environment\n\n```\n  build            Build all docker images.\n  debug            Start Nautobot and its dependencies in debug mode.\n  destroy          Destroy all containers and volumes.\n  restart          Restart Nautobot and its dependencies in detached mode.\n  start            Start Nautobot and its dependencies in detached mode.\n  stop             Stop Nautobot and its dependencies.\n```\n\n### Utility \n\n```\n  cli              Launch a bash shell inside the running Nautobot container.\n  create-user      Create a new user in django (default: admin), will prompt for password.\n  makemigrations   Run Make Migration in Django.\n  nbshell          Launch a nbshell session.\n```\n\n### Testing \n\n```\n  bandit           Run bandit to validate basic static code security analysis.\n  black            Run black to check that Python files adhere to its style standards.\n  flake8           Run flake8 to check that Python files adhere to its style standards.\n  pylint           Run pylint code analysis.\n  pydocstyle       Run pydocstyle to validate docstring formatting adheres to NTC defined standards.\n  tests            Run all tests for this plugin.\n  unittest         Run Django unit tests for the plugin.\n```\n',
    'author': 'Network to Code, LLC',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/nautobot/nautobot-golden-config',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
